Blade Ink Python API
====================

Blade Ink Python provides bindings for the Inkle's Ink <https://github.com/inkle/ink>, a scripting language for writing interactive narratives.

Blade Ink is fully compatible with the reference version and supports all its language features.

To learn more about the Ink language, you can check the official documentation <https://github.com/inkle/ink/blob/master/Documentation/WritingWithInk.md>.

